@@ -90,7 +90,7 @@ class EWAHFBOperator(EWAHBaseOperator):
                     ).format(i_f, "\n\t".join(allowed_insight_fields))
                 )
 
-        assert isinstance(data_since, datetime), "data_from must be of type datetime!"
+        assert isinstance(data_since, datetime), "data_since must be of type datetime!"
 
         if kwargs.get("extract_strategy") == EC.ES_SUBSEQUENT:
             kwargs["subsequent_field"] = "date_start"
@@ -109,9 +109,11 @@ class EWAHFBOperator(EWAHBaseOperator):
             self.extract_strategy == EC.ES_SUBSEQUENT
             and self.test_if_target_table_exists()
         ):
-            data_since = (
-                self.get_max_value_of_column("date_start") - self.refresh_interval
-            )
+            data_since = self.get_max_value_of_column("date_start")
+            if isinstance(data_since, str):
+                # Sometimes the date is saved as string
+                data_since = datetime.strptime(data_since, "%Y-%m-%d").date()
+            data_since = data_since - self.refresh_interval
         else:
             data_since = self.data_since
         for account_id in self.account_ids or []:
